@@ -6,7 +6,7 @@ from plone.supermodel.interfaces import IFieldExportImportHandler
 from plone.supermodel.utils import prettyXML
 from zope.component import getUtility
 
-import unittest2 as unittest
+import unittest
 
 
 SUPERMODEL_XML = """<field name="dummy" type="plone.formwidget.geolocation.GeolocationField">
