@@ -4,7 +4,7 @@ from plone.formwidget.geolocation.testing import GEOLOCATION_INTEGRATION_TESTING
 from zope.component import getUtility
 from zope.schema.interfaces import IVocabularyFactory
 
-import unittest2 as unittest
+import unittest
 
 
 class TestVocabularies(unittest.TestCase):
